pub struct ValidatorSigningInfo {
pub address: String,
pub start_height: i64,
pub index_offset: i64,
pub jailed_until: Option<Timestamp>,
pub tombstoned: bool,
pub missed_blocks_counter: i64,
}Expand description
ValidatorSigningInfo defines a validator’s signing info for monitoring their liveness activity.
Fields
address: Stringstart_height: i64Height at which validator was first a candidate OR was un-jailed
index_offset: i64Index which is incremented every time a validator is bonded in a block and may have signed a pre-commit or not. This in conjunction with the signed_blocks_window param determines the index in the missed block bitmap.
jailed_until: Option<Timestamp>Timestamp until which the validator is jailed due to liveness downtime.
tombstoned: boolWhether or not a validator has been tombstoned (killed out of validator set). It is set once the validator commits an equivocation or for any other configured misbehavior.
missed_blocks_counter: i64A counter of missed (unsigned) blocks. It is used to avoid unnecessary reads in the missed block bitmap.