#[repr(i32)]pub enum AuthorizationType {
Unspecified = 0,
Delegate = 1,
Undelegate = 2,
Redelegate = 3,
CancelUnbondingDelegation = 4,
}Expand description
AuthorizationType defines the type of staking module authorization type
Since: cosmos-sdk 0.43
Variants
Unspecified = 0
AUTHORIZATION_TYPE_UNSPECIFIED specifies an unknown authorization type
Delegate = 1
AUTHORIZATION_TYPE_DELEGATE defines an authorization type for Msg/Delegate
Undelegate = 2
AUTHORIZATION_TYPE_UNDELEGATE defines an authorization type for Msg/Undelegate
Redelegate = 3
AUTHORIZATION_TYPE_REDELEGATE defines an authorization type for Msg/BeginRedelegate
CancelUnbondingDelegation = 4
AUTHORIZATION_TYPE_CANCEL_UNBONDING_DELEGATION defines an authorization type for Msg/MsgCancelUnbondingDelegation
Implementations
Sourceimpl AuthorizationType
impl AuthorizationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AuthorizationType>
pub fn from_str_name(value: &str) -> Option<AuthorizationType>
Creates an enum from field names used in the ProtoBuf definition.