#[repr(i32)]pub enum OrderBy {
Unspecified = 0,
Asc = 1,
Desc = 2,
}Expand description
OrderBy defines the sorting order
Variants
Unspecified = 0
ORDER_BY_UNSPECIFIED specifies an unknown sorting order. OrderBy defaults to ASC in this case.
Asc = 1
ORDER_BY_ASC defines ascending order
Desc = 2
ORDER_BY_DESC defines descending order
Implementations
Sourceimpl OrderBy
impl OrderBy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<OrderBy>
pub fn from_str_name(value: &str) -> Option<OrderBy>
Creates an enum from field names used in the ProtoBuf definition.