#[repr(i32)]pub enum AccessType {
Unspecified = 0,
Nobody = 1,
Everybody = 3,
AnyOfAddresses = 4,
}Expand description
AccessType permission types
Variants
Unspecified = 0
AccessTypeUnspecified placeholder for empty value
Nobody = 1
AccessTypeNobody forbidden
Everybody = 3
AccessTypeEverybody unrestricted
AnyOfAddresses = 4
AccessTypeAnyOfAddresses allow any of the addresses
Implementations
Sourceimpl AccessType
impl AccessType
Sourceimpl AccessType
impl AccessType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AccessType>
pub fn from_str_name(value: &str) -> Option<AccessType>
Creates an enum from field names used in the ProtoBuf definition.