pub enum SequenceStrategyKind {
Query,
QueryAndIncrement,
SetAndIncrement(u64),
Constant(u64),
}Variants
Query
Always query
QueryAndIncrement
Query the first time, and then increment each successful tx
SetAndIncrement(u64)
Set to this the first time, and then increment each successful tx
Constant(u64)
Set to this each time